"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Rules_1 = require("./declare/Rules");
const isProduction = process.env.NODE_ENV === 'production';
/**
 * Vue eslint 规则
 * 普通兼容 anne 1.x
 */
module.exports = {
    root: true,
    env: {
        node: true
    },
    // 允许使用全局变量 将变量设置为 true 将允许变量被重写，false 将不允许被重写。
    globals: {
        lib: false,
        wx: false,
        $: false,
        rrc: true,
        rc: true,
        rcLog: true,
        angular: false,
        FormData: false,
        debugger: false,
        Image: false
    },
    extends: [
        require.resolve('eslint-config-standard'),
        'plugin:vue/base'
    ],
    rules: {
        // 箭头函数有一个参数时可以省略括号
        'arrow-parens': Rules_1.Rules.OFF,
        // 不允许使用分号
        semi: [Rules_1.Rules.ERROR, 'never'],
        // 代码长度 最大是200
        'max-len': [Rules_1.Rules.ERROR, 200, 2],
        // allow async-await
        'generator-star-spacing': Rules_1.Rules.OFF,
        // function 括号之前 可以不用空格
        'space-before-function-paren': Rules_1.Rules.WARN,
        'padded-blocks': Rules_1.Rules.WARN,
        'no-var': Rules_1.Rules.ERROR,
        'no-unused-vars': ['error', {
                'caughtErrors': 'none',
                'argsIgnorePattern': '^_|h',
                'ignoreRestSiblings': true
            }],
        // 允许空的reject
        'prefer-promise-reject-errors': [Rules_1.Rules.ERROR, {
                allowEmptyReject: true
            }],
        // 允许对象属性中 不写驼峰 主要是用于 给后端 传值或者显示后端传输回来的值
        camelcase: [Rules_1.Rules.ERROR, {
                properties: 'never'
            }],
        'no-use-before-define': Rules_1.Rules.ERROR,
        /**
         * 对象后面强制需要 跟一个逗号 该规则 只有多行时 起作用
         * let foo = {
         *  bar: 'baz',
         *  qux: 'quz',
         * }
         */
        'comma-dangle': ['error', {
                arrays: 'only-multiline',
                objects: 'only-multiline',
                imports: 'ignore',
                functions: 'ignore',
                exports: 'ignore'
            }],
        // 不允许重新 原生属性的变量
        'no-extend-native': Rules_1.Rules.ERROR,
        'no-console': isProduction ? 'error' : 'off',
        'no-debugger': isProduction ? 'error' : 'off'
    }
};
